# 🤖 Curated transformers

This Python package provides a curated set of PyTorch transformer models,
composed of reusable modules. Curated transformers currently supports the
following model types:

- ALBERT
- BERT
- CamemBERT
- RoBERTa
- XLM-RoBERTa

## ⚠️ Warning: experimental package

This package is experimental and it is possible that models and APIs will
change in incompatible ways.

## ⏳ Install

```bash
pip install curated-transformers
```
